# Vivarium-core

Vivarium-core provides a process interface and engine for composing multi-scale models in computational biology.

![vivarium](doc/_static/snapshots_fields.png)

## Documentation and Tutorials
Visit [Vivarium documentation](https://vivarium-core.readthedocs.io/)

## Concept

A Vivarium is a "place of life" -- an enclosure for raising organisms in controlled environments for observation or
research. Typical vivaria include aquariums or terrariums.  The vivarium provided in this repository is a computational
vivarium for developing multi-scale models of cells in dynamic environments. Its framework is a synthesis of
hybrid modeling, agent-based modeling, multi-scale simulation, and modular programming.

## Installation
vivarium-core can be used as a python library. To install:

```
$ pip install vivarium-core
```
